@@ -35,11 +35,7 @@ def plot_base_bar1(df: pd.DataFrame, title_name='', subtitle_name='', xaxis_name
         ynames = df.columns.tolist()
     # plot
     _data = df.copy()
-    c1 = Bar()
-    c1.add_xaxis(_data.index.tolist())
-    for icol in ynames:
-        c1.add_yaxis(icol, _data[icol].values.tolist())
-    c1.set_series_opts(label_opts=opts.LabelOpts(is_show=False))
+    c1 = Bar({'bg_color':'white'})
     c1.set_global_opts(
         title_opts=opts.TitleOpts(title=title_name, subtitle=subtitle_name),
         legend_opts=opts.LegendOpts(is_show=True),
@@ -48,6 +44,10 @@ def plot_base_bar1(df: pd.DataFrame, title_name='', subtitle_name='', xaxis_name
         yaxis_opts=opts.AxisOpts(name=yaxis_name),
         datazoom_opts=opts.DataZoomOpts(is_show=True)
     )
+    c1.add_xaxis([str(i) for i in _data.index)
+    for icol in ynames:
+        c1.add_yaxis(icol, _data[icol].values.tolist())
+    c1.set_series_opts(label_opts=opts.LabelOpts(is_show=False))
     if is_save:
         return c1
     else:
@@ -69,11 +69,7 @@ def plot_base_line1(df: pd.DataFrame, title_name='', subtitle_name='', xaxis_nam
         ynames = df.columns.tolist()
     # plot
     _data = df.copy()
-    c1 = Line()
-    c1.add_xaxis(_data.index.tolist())
-    for icol in ynames:
-        c1.add_yaxis(icol, _data[icol].values.tolist())
-    c1.set_series_opts(label_opts=opts.LabelOpts(is_show=False))
+    c1 = Line({'bg_color':'white'})
     c1.set_global_opts(
         title_opts=opts.TitleOpts(title=title_name, subtitle=subtitle_name),
         legend_opts=opts.LegendOpts(is_show=True),
@@ -82,6 +78,10 @@ def plot_base_line1(df: pd.DataFrame, title_name='', subtitle_name='', xaxis_nam
         yaxis_opts=opts.AxisOpts(name=yaxis_name),
         datazoom_opts=opts.DataZoomOpts(is_show=True)
     )
+    c1.add_xaxis([str(i) for i in _data.index])
+    for icol in ynames:
+        c1.add_yaxis(icol, _data[icol].values.tolist())
+    c1.set_series_opts(label_opts=opts.LabelOpts(is_show=False))
     if is_save:
         return c1
     else:
@@ -101,7 +101,7 @@ def plot_base_line2(df1: pd.DataFrame, df2: pd.DataFrame,
     _data1 = df1.copy()
     _data2 = df2.copy()
     # plot
-    c1 = Line()
+    c1 = Line({'bg_color':'white'})
     c1.set_global_opts(
         title_opts=opts.TitleOpts(title=title_name, subtitle=subtitle_name),
         legend_opts=opts.LegendOpts(is_show=True),
@@ -136,8 +136,8 @@ def plot_base_grid1(df1: pd.DataFrame, df2: pd.DataFrame,
 
     # plot1
     _data = df1.copy()
-    c1 = Line()
-    c1.add_xaxis([str(i) for i in _data.index.tolist()])
+    c1 = Line({'bg_color':'white'})
+    c1.add_xaxis([str(i) for i in _data.index])
     for icol in _data.columns.tolist():
         c1.add_yaxis(str(icol), _data[icol].values.tolist())
     c1.set_series_opts(label_opts=opts.LabelOpts(is_show=False))
@@ -156,8 +156,8 @@ def plot_base_grid1(df1: pd.DataFrame, df2: pd.DataFrame,
     )
     # plot2
     _data = df2.copy()
-    c2 = Line()
-    c2.add_xaxis([str(i) for i in _data.index.tolist()])
+    c2 = Line({'bg_color':'white'})
+    c2.add_xaxis([str(i) for i in _data.index])
     for icol in _data.columns.tolist():
         c2.add_yaxis(str(icol), _data[icol].values.tolist())
     c2.set_series_opts(label_opts=opts.LabelOpts(is_show=False))
